pub struct i127(/* private fields */);Expand description
The 127-bit signed integer type.
Implementations
Sourceimpl i127
impl i127
Sourcepub fn min_value() -> i127
pub fn min_value() -> i127
Returns the smallest value that can be represented by this integer type.
Sourcepub fn max_value() -> i127
pub fn max_value() -> i127
Returns the largest value that can be represented by this integer type.
Sourcepub const fn new(value: i128) -> i127
pub const fn new(value: i128) -> i127
Crates a new variable
This function mainly exists as there is currently not a better way to construct these types. May be deprecated or removed if a better way to construct these types becomes available.
Examples
Basic usage:
use ux::*;
assert_eq!(u31::new(64), u31::from(64u8));
Panic
This function will panic if value is not representable by this type
Sourcepub fn wrapping_sub(self, rhs: i127) -> i127
pub fn wrapping_sub(self, rhs: i127) -> i127
Wrapping (modular) subtraction. Computes self - other,
wrapping around at the boundary of the type.
Examples
Basic usage:
use ux::*;
assert_eq!(i5::MIN.wrapping_sub(i5::new(1)), i5::MAX);
assert_eq!(i5::new(-10).wrapping_sub(i5::new(5)), i5::new(-15));
assert_eq!(i5::new(-15).wrapping_sub(i5::new(5)), i5::new(12));Sourcepub fn wrapping_add(self, rhs: i127) -> i127
pub fn wrapping_add(self, rhs: i127) -> i127
Wrapping (modular) addition. Computes self + other,
wrapping around at the boundary of the type.
Examples
Basic usage:
use ux::*;
assert_eq!(i5::MAX.wrapping_add(i5::new(1)), i5::MIN);
assert_eq!(i5::new(10).wrapping_add(i5::new(5)), i5::new(15));
assert_eq!(i5::new(15).wrapping_add(i5::new(5)), i5::new(-12));Trait Implementations
Sourceimpl BitAndAssign for i127
impl BitAndAssign for i127
Sourcefn bitand_assign(&mut self, other: i127)
fn bitand_assign(&mut self, other: i127)
Performs the
&= operation. Read moreSourceimpl BitOrAssign for i127
impl BitOrAssign for i127
Sourcefn bitor_assign(&mut self, other: i127)
fn bitor_assign(&mut self, other: i127)
Performs the
|= operation. Read moreSourceimpl BitXorAssign for i127
impl BitXorAssign for i127
Sourcefn bitxor_assign(&mut self, other: i127)
fn bitxor_assign(&mut self, other: i127)
Performs the
^= operation. Read moreSourceimpl Ord for i127
impl Ord for i127
Sourceimpl PartialOrd for i127
impl PartialOrd for i127
Sourceimpl<T> ShlAssign<T> for i127
impl<T> ShlAssign<T> for i127
Sourcefn shl_assign(&mut self, rhs: T)
fn shl_assign(&mut self, rhs: T)
Performs the
<<= operation. Read moreSourceimpl<T> ShrAssign<T> for i127
impl<T> ShrAssign<T> for i127
Sourcefn shr_assign(&mut self, rhs: T)
fn shr_assign(&mut self, rhs: T)
Performs the
>>= operation. Read moreimpl Copy for i127
impl Eq for i127